"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.SlackService = void 0;
const tslib_1 = require("tslib");
const common_1 = require("@nestjs/common");
const constants_1 = require("./constants");
const utils_1 = require("./utils");
let SlackService = class SlackService {
    constructor(options, client, log) {
        this.options = options;
        this.client = client;
        this.log = log;
    }
    sendText(text, opts) {
        return this.postMessage(Object.assign({ text }, opts));
    }
    sendBlocks(blocks, opts) {
        return this.postMessage(Object.assign({ blocks }, opts));
    }
    postMessage(req) {
        return tslib_1.__awaiter(this, void 0, void 0, function* () {
            if (!req.channel) {
                utils_1.invariant(this.options.defaultChannel, 'neither channel nor defaultChannel was applied');
                req.channel = this.options.defaultChannel;
            }
            const requestTypes = {
                api: () => tslib_1.__awaiter(this, void 0, void 0, function* () { return this.runApiRequest(req); }),
                stdout: () => tslib_1.__awaiter(this, void 0, void 0, function* () { return this.runStdoutRequest(req); }),
                google: () => tslib_1.__awaiter(this, void 0, void 0, function* () { return this.runGoogleLoggingRequest(req); }),
            };
            yield requestTypes[this.options.type]();
        });
    }
    runApiRequest(req) {
        return tslib_1.__awaiter(this, void 0, void 0, function* () {
            utils_1.invariant(this.client, 'expected this.client to be WebClient');
            utils_1.invariant(req.channel, 'expected channel to be applied');
            yield this.client.chat.postMessage(req);
        });
    }
    runStdoutRequest(req) {
        return tslib_1.__awaiter(this, void 0, void 0, function* () {
            this.options.output(req);
        });
    }
    runGoogleLoggingRequest(req) {
        return tslib_1.__awaiter(this, void 0, void 0, function* () {
            const metadata = {
                severity: 'NOTICE',
                'logging.googleapis.com/labels': { type: 'nestjs-slack' },
                'logging.googleapis.com/operation': {
                    producer: 'github.com/bjerkio/nestjs-slack',
                },
            };
            utils_1.invariant(this.log, 'expected Google Logger instance');
            yield this.log.write(this.log.entry(metadata, req));
        });
    }
};
SlackService = tslib_1.__decorate([
    common_1.Injectable(),
    tslib_1.__param(0, common_1.Inject(constants_1.SLACK_MODULE_OPTIONS)),
    tslib_1.__param(1, common_1.Inject(constants_1.SLACK_WEB_CLIENT)),
    tslib_1.__param(2, common_1.Inject(constants_1.GOOGLE_LOGGING)),
    tslib_1.__metadata("design:paramtypes", [Object, Function, Function])
], SlackService);
exports.SlackService = SlackService;
